@@ -20,6 +20,8 @@ class Config(BaseModel):
     """bilibili cookies"""
     parser_ytb_ck: str | None = None
     """youtube cookies"""
+    parser_xhs_ck: str | None = None
+    """小红书 cookies"""
     parser_proxy: str | None = None
     """代理"""
     parser_need_upload: bool = False
@@ -113,6 +115,11 @@ class Config(BaseModel):
         """youtube cookies"""
         return self.parser_ytb_ck
 
+    @property
+    def xhs_ck(self) -> str | None:
+        """小红书 cookies"""
+        return self.parser_xhs_ck
+
     @property
     def proxy(self) -> str | None:
         """代理"""
