@@ -43,3 +43,10 @@ class PlatformEnum(str, Enum):
 
     def __str__(self) -> str:
         return self.value
+
+
+class RenderType(str, Enum):
+    default = "default"
+    common = "common"
+    htmlkit = "htmlkit"
+    htmlrender = "htmlrender"
