@@ -36,9 +36,7 @@ class NGAParser(BaseParser):
     # ("ngabbs.com", r"https?://ngabbs\.com/read\.php\?tid=(?P<tid>\d+)(?:[&#A-Za-z\d=_-]+)?"),
     # ("nga.178.com", r"https?://nga\.178\.com/read\.php\?tid=(?P<tid>\d+)(?:[&#A-Za-z\d=_-]+)?"),
     # ("bbs.nga.cn", r"https?://bbs\.nga\.cn/read\.php\?tid=(?P<tid>\d+)(?:[&#A-Za-z\d=_-]+)?"),
-    @handle("ngabbs.com", r"tid=(?P<tid>\d+)")
-    @handle("nga.178.com", r"tid=(?P<tid>\d+)")
-    @handle("bbs.nga.cn", r"tid=(?P<tid>\d+)")
+    @handle("nga", r"tid=(?P<tid>\d+)")
     async def _parse(self, searched: re.Match[str]):
         # 从匹配对象中获取原始URL
         tid = searched.group("tid")
